@@ -33,10 +33,16 @@
 #  define VTKCOMMONARCHIVE_DEPRECATED_NO_EXPORT VTKCOMMONARCHIVE_NO_EXPORT VTKCOMMONARCHIVE_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef VTKCOMMONARCHIVE_NO_DEPRECATED
 #    define VTKCOMMONARCHIVE_NO_DEPRECATED
 #  endif
 #endif
 
+/* VTK-HeaderTest-Exclude: vtkCommonArchiveModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
 #endif /* VTKCOMMONARCHIVE_EXPORT_H */
