@@ -33,10 +33,16 @@
 #  define VTKIOLAS_DEPRECATED_NO_EXPORT VTKIOLAS_NO_EXPORT VTKIOLAS_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef VTKIOLAS_NO_DEPRECATED
 #    define VTKIOLAS_NO_DEPRECATED
 #  endif
 #endif
 
+/* VTK-HeaderTest-Exclude: vtkIOLASModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
 #endif /* VTKIOLAS_EXPORT_H */
