@@ -33,10 +33,16 @@
 #  define VTKIOODBC_DEPRECATED_NO_EXPORT VTKIOODBC_NO_EXPORT VTKIOODBC_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef VTKIOODBC_NO_DEPRECATED
 #    define VTKIOODBC_NO_DEPRECATED
 #  endif
 #endif
 
+/* VTK-HeaderTest-Exclude: vtkIOODBCModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
 #endif /* VTKIOODBC_EXPORT_H */
