@@ -33,10 +33,16 @@
 #  define VTKIOOPENVDB_DEPRECATED_NO_EXPORT VTKIOOPENVDB_NO_EXPORT VTKIOOPENVDB_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef VTKIOOPENVDB_NO_DEPRECATED
 #    define VTKIOOPENVDB_NO_DEPRECATED
 #  endif
 #endif
 
+/* VTK-HeaderTest-Exclude: vtkIOOpenVDBModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
 #endif /* VTKIOOPENVDB_EXPORT_H */
