@@ -33,6 +33,7 @@
 #  define VTKRENDERINGVR_DEPRECATED_NO_EXPORT VTKRENDERINGVR_NO_EXPORT VTKRENDERINGVR_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef VTKRENDERINGVR_NO_DEPRECATED
 #    define VTKRENDERINGVR_NO_DEPRECATED
@@ -43,20 +44,5 @@
 
 /* Include ABI Namespace */
 #include "vtkABINamespace.h"
-/* AutoInit dependencies. */
-#include "vtkIOImageModule.h"
-#include "vtkInteractionStyleModule.h"
-#include "vtkRenderingOpenGL2Module.h"
-#include "vtkRenderingVolumeOpenGL2Module.h"
-
-
-/* AutoInit implementations. */
-#ifdef vtkRenderingVR_AUTOINIT_INCLUDE
-#include vtkRenderingVR_AUTOINIT_INCLUDE
-#endif
-#ifdef vtkRenderingVR_AUTOINIT
-#include "vtkAutoInit.h"
-VTK_MODULE_AUTOINIT(vtkRenderingVR)
-#endif
 
 #endif /* VTKRENDERINGVR_EXPORT_H */
